@@ -2,5 +2,5 @@ from .csv import CSVMicroService
 from .mail import MailMicroService
 from .odoo import OdooMicroService
 from .s3 import S3MicroService
-from .psql import PsqlMicroService
-from .jinja import JinjaRenderMicroservice
+from .jinja import JinjaRenderMicroService
+from .sql import SqlMicroService
